# ---
# R code for: Differential provisioning roles, prey size, and prey abundance
#   shape the dynamic feeding behavior of a social carnivore (Gable et al.)

# Journal: Communications Biology

# contact: Sean M. Johnson-Bice
#           University of Manitoba
#           Dept. of Biological Sciences
# year: 2023
# email: s.johnsonbice@gmail.com
# ---

# Load packages
library(tidyverse)
library(lubridate)
library(lme4)
library(mgcv)
library(gratia)
library(ggeffects)
library(emmeans)
library(viridis)
library(ggpubr)
library(performance)
library(broom.mixed)

#' reading in data
killDat<-read_csv("Gable_et_al_wolf_provisioning_handling_data.csv")

#'converting timestamp to dates
killDat$killDate<-as.POSIXct(killDat$killDate, format = "%m/%d/%y", tz="America/Chicago")
killDat$ordinalDay<-yday(killDat$killDate) #ordinal date
killDat$avgTime<-(killDat$minTime+killDat$maxTime)/2 #avg of "min/max time at kill" = handling time estimate
killDat$year <- as.factor(killDat$year)

# Convert some variables to factors
killDat$wolfID <- factor(killDat$wolfID)
killDat$prey <- factor(killDat$prey)
killDat$breedStatus <- factor(killDat$breedStatus)

# log-transform handling time
killDat$avgTime_log <- log(killDat$avgTime)
# calculate per-capita prey biomass by pack size and wolf density
killDat <- killDat %>%
  mutate(packBiomass = biomassIndex/avgPackSize)

# Create 1/0 variable for return to kill/home sites
killDat <- killDat %>% 
  mutate(return_kill = case_when(returnToKill == "Yes" ~ 1,
                                 returnToKill == "No" ~ 0,
                                 TRUE ~ NA_real_),
         return_homesite = case_when(returnToHomesite == "Yes" ~ 1,
                                     returnToHomesite == "No" ~ 0,
                                     TRUE ~ NA_real_))

# Create a new variable for handling time, where HT's >20 are all lumped together
killDat <- killDat %>%
  mutate(avgTime_cat = case_when(avgTime < 21 ~ ceiling(avgTime),
                                 TRUE ~ 21))

# Scale ordinal day for better model fitting in GLMER models
killDat$ordinalDay_S <- scale(killDat$ordinalDay)[,1]

# Summary statistics on handling time by prey
killDat %>%
  group_by(prey) %>%
  summarize(median = median(avgTime),
            sd = sd(avgTime))

# Summary statistics on handling time by prey, breeding status
killDat %>%
  group_by(prey, breedStatus) %>%
  summarize(median = median(avgTime),
            sd = sd(avgTime))

###### Fig. 2: Handling time histogram plot ######

# Create histogram for each prey: Fawns (Fig. 2a)
fawn_HT_hist <- killDat %>% filter(prey == "Fawn") %>%
  ggplot(aes(x=avgTime_cat, y = after_stat(count)/sum(count))) +
  geom_bar(fill = "#FB9A06", color = "#FB9A06", alpha=0.4,
           position=position_nudge((x=-.5))) + 
  geom_vline(xintercept = 2, linetype = "dashed") +
  scale_y_continuous(labels=scales::percent, limits=c(0,.3)) +
  scale_x_continuous(breaks = c(2,5,10,15,20.5),
                     labels = c("2","5","10","15","20+"),
                     expand = expansion(c(0.02,.02))) +
  theme_bw() + 
  theme(panel.grid.major.x = element_blank(), axis.title = element_blank()) +
  annotate("text", label = "(a)", x=20, y=.295, size=4)
fawn_HT_hist

# Create histogram for each prey: Beaver (Fig. 2b)
beav_HT_hist <- killDat %>% filter(prey != "Fawn") %>%
  ggplot(aes(x=avgTime_cat, y = after_stat(count)/sum(count))) +
  geom_bar(fill = "#4B0C6B", color = "#4B0C6B", alpha=0.4,
           position=position_nudge((x=-.5))) + 
  geom_vline(xintercept = 2, linetype = "dashed") +
  scale_y_continuous(labels=scales::percent, limits=c(0,.3)) +
  scale_x_continuous(breaks = c(2,5,10,15,20.5),
                     labels = c("2","5","10","15","20+"),
                     expand = expansion(c(0.02,.02))) +
  theme_bw() + 
  theme(panel.grid.major.x = element_blank(), axis.title = element_blank()) +
  annotate("text", label = "(b)", x=20, y=.295, size=4)
beav_HT_hist

# Combine figs and add common axis titles (Fig. 2a-b)
# (Silhouettes added via graphic design software)
prey_HT_hist <- ggarrange(fawn_HT_hist, beav_HT_hist, nrow = 2)
annotate_figure(prey_HT_hist,
                left = text_grob("Percentage of kills found", rot=90),
                bottom = text_grob("Handling time (hrs)"))




###################################
### Model 1: Prey handling time ###
###################################

###### Fit Model ###### 
# GAM model w/ group-level smoothers on ordinalDay by pack status
# plus random intercept terms for wolf ID and year
prey_ht_log_gam <- gam(avgTime_log ~ breedStatus + prey + packBiomass +
                              s(ordinalDay, by=breedStatus, m=2, k=9, bs="tp") + 
                              s(wolfID, bs="re", k=33) + s(year, bs = "re", k=6),
                            data = killDat)
draw(prey_ht_log_gam)
appraise(prey_ht_log_gam)
gam.check(prey_ht_log_gam)
summary(prey_ht_log_gam)


###### Fig. 3: Handling time plots by prey type ######
# Create data grid to predict model onto
prey_ht_grid <- expand.grid(ordinalDay = seq(105,245,2),
                       wolfID = "B3S", # Any wolf ID is fine; excluded in prediction
                       year = 2019, # Any year is fine; excluded in prediction
                       prey = unique(killDat$prey),
                       packBiomass = mean(killDat$packBiomass),
                       breedStatus = unique(killDat$breedStatus))

# Predict from the prey handling time model
prey_ht_pred <- predict(prey_ht_log_gam,
                         newdata = prey_ht_grid,
                         se.fit = TRUE,
                         exclude = c("s(wolfID)", "s(year)"))

prey_ht_grid$fit <- as.numeric(prey_ht_pred$fit)
prey_ht_grid$se <- as.numeric(prey_ht_pred$se.fit)


# Plot handling times of fawn kills by breeding status (Fig. 3a)
fawn_HT_plot <- prey_ht_grid %>% 
  filter(prey == "Fawn" & ordinalDay > 142) %>%
  ggplot(aes(x=ordinalDay, y=exp(fit), fill=breedStatus, color=breedStatus,
             linetype=breedStatus)) +
  geom_ribbon(aes(ymin = exp(fit-(1.96*se)), ymax = exp(fit+(1.96*se))), alpha=0.6) +
  geom_line() + theme_bw() +
  theme(panel.grid.minor = element_blank(), axis.title = element_blank(),
        legend.position = "none") +
  scale_linetype_manual(values=c("solid","dashed")) +
  scale_color_manual(values=c("#FB9A06","#FB9A06")) +
  scale_fill_manual(values=c("#FB9A06","#FDCC82")) +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)),
                     limits=c(0.5,14.5),
                     breaks = c(3,6,9,12)) +
  scale_x_continuous(expand=expansion(mult=c(0.02,0.02)),
                     breaks = c(121, 152, 182, 213),
                     labels = c("May 1", "Jun. 1", "Jul. 1", "Aug. 1"), 
                     limits = c(105,245))

# Plot handling times of beaver kills by breeding status (Fig. 3b)
beaver_HT_plot <- prey_ht_grid %>% 
  filter(prey == "Beaver") %>%
  ggplot(aes(x=ordinalDay, y=exp(fit), fill=breedStatus, color=breedStatus,
             linetype=breedStatus)) +
  geom_ribbon(aes(ymin = exp(fit-(1.96*se)), ymax = exp(fit+(1.96*se))), alpha=0.6) +
  geom_line() + theme_bw() +
  theme(panel.grid.minor = element_blank(), axis.title = element_blank(),
        legend.position = "none") +
  scale_linetype_manual(values=c("solid","dashed")) +
  scale_color_manual(values=c("#4B0C6B","#4B0C6B")) +
  scale_fill_manual(values=c("#4B0C6B","#A485B4")) +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)),
                     limits=c(0.5,14.5),
                     breaks = c(3,6,9,12)) +
  scale_x_continuous(expand=expansion(mult=c(0.02,0.02)),
                     breaks = c(121, 152, 182, 213),
                     labels = c("May 1", "Jun. 1", "Jul. 1", "Aug. 1"))

# Plot handling times of kills from breeding animals (Fig. 3c)
# Only include fawn predictions from May 26 onward (avg. parturition date)
breeder_HT_plot <- ggplot() +
  geom_ribbon(aes(ymin = exp(fit-(1.96*se)), ymax = exp(fit+(1.96*se)), x=ordinalDay), 
              alpha=0.6, fill="#4B0C6B", color="#4B0C6B",
              data = filter(prey_ht_grid, prey=="Beaver" & breedStatus == "Breeding")) +
  geom_line(aes(y=exp(fit), x=ordinalDay), color="#4B0C6B", 
            data = filter(prey_ht_grid, prey=="Beaver" & breedStatus == "Breeding")) + 
  geom_ribbon(aes(ymin = exp(fit-(1.96*se)), ymax = exp(fit+(1.96*se)), x=ordinalDay), 
              alpha=0.6, fill="#FB9A06", color="#FB9A06",
              data = filter(prey_ht_grid, prey=="Fawn" & breedStatus == "Breeding"&
                              ordinalDay>145)) +
  geom_line(aes(y=exp(fit), x=ordinalDay), color="#FB9A06", 
            data = filter(prey_ht_grid, prey=="Fawn" & breedStatus == "Breeding" &
                            ordinalDay>145)) +
  theme_bw() +
  theme(panel.grid.minor = element_blank()) +
  labs(y="", x="") +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)),
                     limits=c(0.5,14.5),
                     breaks = c(3,6,9,12)) +
  scale_x_continuous(expand=expansion(mult=c(0.02,0.02)),
                     breaks = c(121, 152, 182, 213),
                     labels = c("May 1", "Jun. 1", "Jul. 1", "Aug. 1"))

# Plot handling times of kills from subordinate animals (Fig. 3d)
# Only include fawn predictions from May 26 onward (avg. parturition date)
subordinate_HT_plot <- ggplot() +
  geom_ribbon(aes(ymin = exp(fit-(1.96*se)), ymax = exp(fit+(1.96*se)), x=ordinalDay), 
              alpha=0.6, fill="#A485B4", color="#4B0C6B", linetype="dashed",
              data = filter(prey_ht_grid, prey=="Beaver" & breedStatus != "Breeding")) +
  geom_line(aes(y=exp(fit), x=ordinalDay), color="#4B0C6B", linetype="dashed",
            data = filter(prey_ht_grid, prey=="Beaver" & breedStatus != "Breeding")) + 
  geom_ribbon(aes(ymin = exp(fit-(1.96*se)), ymax = exp(fit+(1.96*se)), x=ordinalDay), 
              alpha=0.6, fill="#FDCC82", color="#FB9A06", linetype="dashed",
              data = filter(prey_ht_grid, prey=="Fawn" & breedStatus != "Breeding"&
                              ordinalDay>145)) +
  geom_line(aes(y=exp(fit), x=ordinalDay), color="#FB9A06", linetype="dashed",
            data = filter(prey_ht_grid, prey=="Fawn" & breedStatus != "Breeding" &
                            ordinalDay>145)) +
  theme_bw() +
  theme(panel.grid.minor = element_blank(), axis.title = element_blank()) +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)),
                     limits=c(0.5,14.5),
                     breaks = c(3,6,9,12)) +
  scale_x_continuous(expand=expansion(mult=c(0.02,0.02)),
                     breaks = c(121, 152, 182, 213),
                     labels = c("May 1", "Jun. 1", "Jul. 1", "Aug. 1")) 


# Combine all handling time plots together for final Figure 3
# *Note: Text and legends were added using graphic design software
ggarrange(fawn_HT_plot, beaver_HT_plot, breeder_HT_plot, subordinate_HT_plot,
          nrow=2, ncol=2)


#################################

###### Fig. 4: Handling time vs. prey biomass per wolf plot ######

# Create avg. pack biomass predicted grid at bi-weekly intervals
packBiomass_HT_grid <- expand.grid(ordinalDay = c(121,136,152,167,182,197,213,228),
                                   wolfID = "B3S",
                                   year = 2019,
                                   prey = unique(killDat$prey),
                                   packBiomass = seq(1,1.35,.01),
                                   breedStatus = unique(killDat$breedStatus))

# Now predict from the model
packBiomass_HT_pred <- predict(prey_ht_log_gam,
                               newdata = packBiomass_HT_grid,
                               se.fit = TRUE,
                               exclude = c("s(wolfID)", "s(year)"))
packBiomass_HT_grid$fit <- as.numeric(packBiomass_HT_pred$fit)
packBiomass_HT_grid$se <- as.numeric(packBiomass_HT_pred$se.fit)
packBiomass_HT_grid$ordinalDay <- as.factor(packBiomass_HT_grid$ordinalDay)


# Breeding wolf fawn HT vs. prey biomass per wolf (Fig. 4a)
breeding_fawn_packBiomass_plot <- packBiomass_HT_grid %>% 
  filter(prey == "Fawn" & breedStatus == "Breeding") %>%
  filter(ordinalDay %in% c(152,167,182,197,213,228)) %>%
  ggplot(aes(x=packBiomass, y=exp(fit), color = ordinalDay)) +
  geom_line() +
  scale_color_viridis(option="inferno", begin = 0.3, end=0.925, discrete = TRUE) +
  theme_bw() +
  theme(panel.grid.minor = element_blank(), legend.position = "none",
        axis.title = element_blank()) +
  scale_x_continuous(expand=expansion(mult=c(0.02,0.02))) +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)), limits = c(1.5,10))
breeding_fawn_packBiomass_plot

# Subordinate wolf fawn HT vs. prey biomass per wolf (Fig. 4b)
subordinate_fawn_packBiomass_plot <- packBiomass_HT_grid %>% 
  filter(prey == "Fawn" & breedStatus == "Subordinate") %>%
  filter(ordinalDay %in% c(152,167,182,197,213,228)) %>%
  ggplot(aes(x=packBiomass, y=exp(fit), color = ordinalDay)) +
  geom_line() +
  scale_color_viridis(option="inferno", begin = 0.3, end=0.925, discrete = TRUE, 
                      labels = c("Jun. 1","Jun. 16","Jul. 1","Jul. 16","Aug. 1","Aug. 16")) +
  theme_bw() +
  theme(panel.grid.minor = element_blank(), axis.title = element_blank(),
        legend.position = "none") +
  scale_x_continuous(expand=expansion(mult=c(0.02,0.02))) +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)), limits = c(1.5,10))
subordinate_fawn_packBiomass_plot

# Breeding wolf beaver HT vs. prey biomass per wolf (Fig. 4c)
breeding_beav_packBiomass_plot <- packBiomass_HT_grid %>% 
  filter(prey == "Beaver" & breedStatus == "Breeding") %>%
  ggplot(aes(x=packBiomass, y=exp(fit), color = ordinalDay)) +
  geom_line() +
  scale_color_viridis(option="inferno", begin = 0.05, end=0.925, discrete = TRUE) +
  theme_bw() +
  theme(panel.grid.minor = element_blank(), legend.position = "none",
        axis.title = element_blank()) +
  scale_x_continuous(expand=expansion(mult=c(0.02,0.02))) +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)), limits = c(1.5,10))
breeding_beav_packBiomass_plot

# Subordinate wolf beaver HT vs. prey biomass per wolf (Fig. 4d)
subordinate_beav_packBiomass_plot <- packBiomass_HT_grid %>% 
  filter(prey == "Beaver" & breedStatus == "Subordinate") %>%
  ggplot(aes(x=packBiomass, y=exp(fit), color = ordinalDay)) +
  geom_line() +
  scale_color_viridis(option="inferno", begin = 0.3, end=0.925, discrete = TRUE, 
                      labels = c("May 1","May 16","Jun. 1","Jun. 16","Jul. 1",
                                 "Jul. 16","Aug. 1","Aug. 16")) +  theme_bw() +
  theme(panel.grid.minor = element_blank(), legend.position = "none",
        axis.title = element_blank()) +
  labs(color="Date") +
  scale_x_continuous(expand=expansion(mult=c(0.02,0.02))) +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)), limits = c(1.5,10))
subordinate_beav_packBiomass_plot

# Combine all biomass vs. handling time plots for final Figure 3
# Silhouettes, legend, and panel letters added w/graphic design software
biomass_ht_plots <- ggarrange(breeding_fawn_packBiomass_plot, 
          subordinate_fawn_packBiomass_plot,
          breeding_beav_packBiomass_plot, 
          subordinate_beav_packBiomass_plot,
          ncol=2, nrow = 2)
annotate_figure(biomass_ht_plots,
                bottom = text_grob("Prey biomass per wolf"),
                left = text_grob("Estimated handling time (hrs)", rot=90))


###########################################
### Models 2,3: Return to kill/homesite ###
###########################################

# Fit logistic glmm to return to kill
kill_return_glmm <- glmer(return_kill ~ ordinalDay_S*breedStatus + prey + packBiomass +
                           (1|wolfID),
                         family = binomial(link = "logit"),
                         data = killDat)
summary(kill_return_glmm)
broom.mixed::tidy(kill_return_glmm, conf.int=TRUE)

# Fit glmm to return to homesite
homesite_return_glmm <- glmer(return_homesite ~ ordinalDay_S*breedStatus + packBiomass + prey +
                               (1|wolfID),
                             family = binomial(link = "logit"),
                             data = killDat,
                             control = glmerControl(optimizer = "bobyqa", # helps with convergence
                                                    optCtrl = list(maxfun=2e6)))
summary(homesite_return_glmm)
broom.mixed::tidy(homesite_return_glmm, conf.int=TRUE)


###### Fig. 5: Return to kill/homesite plots ######

# Return to kill by ordinal day and breeding status plot (Fig. 5a)
kill_return_pred <- ggemmeans(kill_return_glmm, 
                              terms = c("ordinalDay_S [all]","breedStatus"))
kill_return_plot <- ggplot(aes(x=x, y=predicted, color=group, fill=group),
                           data=kill_return_pred) +
  geom_ribbon(aes(ymin=conf.low, ymax=conf.high, linetype=group), 
              alpha=0.5) +
  geom_line() +
  scale_color_viridis(option="inferno", begin = 0.1, end=0.9, discrete = TRUE) +
  scale_fill_viridis(option="inferno", begin = 0.1, end=0.9, discrete = TRUE) +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)), limits=c(.05,1)) +
  scale_x_continuous(expand=expansion(mult=c(0.02,0.02)),
                     breaks = c(-1.95, -.9069, .11048, 1.1618),
                     labels = c("May 1", "Jun. 1", "Jul. 1", "Aug. 1")) +
  theme_bw() + 
  theme(panel.grid.minor = element_blank(), legend.title = element_blank(),
        legend.text = element_text(size=10), axis.title.x = element_blank()) +
  labs(y="Probability of returning to kill")
kill_return_plot

# Return to kill by prey biomass and breeding status (Fig. 5b)
kill_return_biomass_pred <- ggemmeans(kill_return_glmm, 
                                      terms = c("packBiomass [1:1.35 by=0.01]", 
                                                "breedStatus"))
kill_return_biomass_plot <- ggplot(aes(x=x, y=predicted, color=group, fill=group),
                                   data=kill_return_biomass_pred) +
  geom_ribbon(aes(ymin=conf.low, ymax=conf.high, linetype=group), 
              alpha=0.5) +
  geom_line() +
  scale_color_viridis(option="inferno", begin = 0.1, end=0.9, discrete = TRUE) +
  scale_fill_viridis(option="inferno", begin = 0.1, end=0.9, discrete = TRUE) +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)), limits=c(.05,1)) +
  scale_x_continuous(expand=expansion(mult=c(0.02,0.02))) +
  theme_bw() + 
  theme(panel.grid.minor = element_blank(), legend.title = element_blank(),
        legend.text = element_text(size=10), axis.title = element_blank())
kill_return_biomass_plot

# Return to kill by prey type (Fig. 5c)
kill_return_prey_pred <- ggemmeans(kill_return_glmm, 
                                   terms = "prey")
kill_return_prey_plot <- ggplot(aes(x=x, y=predicted, color=x), data=kill_return_prey_pred) +
  geom_point() +
  geom_errorbar(aes(ymin=conf.low, ymax=conf.high), width=0.6) +
  theme_bw() + 
  theme(legend.position = "none", legend.title = element_blank(),
        axis.title.y = element_blank(), axis.title.x=element_blank(),
        axis.ticks.x = element_blank(), panel.grid.minor = element_blank()) +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)), limits=c(.05,1)) +
  scale_color_manual(values = c("#4B0C6B", "#FB9A06")) +
  scale_x_discrete(labels = c("",""))
kill_return_prey_plot


# Return to homesite by ordinal day and breeding status plot (Fig. 5d)
homesite_return_pred <- ggemmeans(homesite_return_glmm, 
                                  terms = c("ordinalDay_S [all]","breedStatus"),
                                  type = "fe")
homesite_return_plot <- ggplot(aes(x=x, y=predicted, color=group, fill=group),
                               data=homesite_return_pred) +
  geom_ribbon(aes(ymin=conf.low, ymax=conf.high, linetype=group), 
              alpha=0.5) +
  geom_line() +
  scale_color_viridis(option="inferno", begin = 0.1, end=0.9, discrete = TRUE) +
  scale_fill_viridis(option="inferno", begin = 0.1, end=0.9, discrete = TRUE) +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)), limits=c(.05,1)) +
  scale_x_continuous(expand=expansion(mult=c(0.02,0.02)),
                     breaks = c(-1.95, -.9069, .11048, 1.1618),
                     labels = c("May 1", "Jun. 1", "Jul. 1", "Aug. 1")) +
  theme_bw() + 
  theme(panel.grid.minor = element_blank(), legend.title = element_blank(),
        legend.text = element_text(size=10)) +
  labs(y="Probability of returning to homesite after kill",
       x="Date")
homesite_return_plot

# Return to homesite by prey biomass and breeding status (Fig. 5e)
homesite_return_biomass_pred <- ggemmeans(homesite_return_glmm, 
                                          terms = c("packBiomass [1:1.35 by=0.01]", 
                                                    "breedStatus"))
homesite_return_biomass_plot <- ggplot(aes(x=x, y=predicted, color=group, fill=group),
                                       data=homesite_return_biomass_pred) +
  geom_ribbon(aes(ymin=conf.low, ymax=conf.high, linetype=group), 
              alpha=0.5) +
  geom_line() +
  scale_color_viridis(option="inferno", begin = 0.1, end=0.9, discrete = TRUE) +
  scale_fill_viridis(option="inferno", begin = 0.1, end=0.9, discrete = TRUE) +
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)), limits=c(.05,1)) +
  scale_x_continuous(expand=expansion(mult=c(0.02,0.02))) +
  theme_bw() + 
  theme(panel.grid.minor = element_blank(), legend.title = element_blank(),
        legend.text = element_text(size=10), axis.title.y = element_blank()) +
  labs(x="Prey biomass per wolf")
homesite_return_biomass_plot

# Return to homesite by prey type (Fig. 5f)
homesite_return_prey_pred <- ggemmeans(homesite_return_glmm, 
                                       terms = "prey")
homesite_return_prey_plot <- ggplot(aes(x=x, y=predicted, color=x), 
                                    data=homesite_return_prey_pred) +
  geom_point() +
  geom_errorbar(aes(ymin=conf.low, ymax=conf.high), width=0.6) +
  theme_bw() + 
  scale_y_continuous(expand=expansion(mult=c(0.02,0.02)), limits=c(.05,1)) +
  theme(legend.position = "none", legend.title = element_blank(),
        axis.title.y = element_blank(), axis.ticks.x = element_blank(),
        panel.grid.minor = element_blank()) +
  labs(x="Prey type") +
  scale_color_manual(values = c("#4B0C6B", "#FB9A06")) +
  scale_x_discrete(labels = c("",""))
homesite_return_prey_plot


# Combine all plots into one large figure (Figure 5a-f)
return_rank_plots <- ggarrange(kill_return_plot, kill_return_biomass_plot,
                               homesite_return_plot, homesite_return_biomass_plot,
                               nrow=2, ncol=2, common.legend = TRUE, 
                               heights=c(.95,1), widths = c(1,.95,1,.95))
return_prey_plots <- ggarrange(kill_return_prey_plot, homesite_return_prey_plot, 
                               nrow=2, common.legend = TRUE, heights=c(.95,1))
ggarrange(return_rank_plots,return_prey_plots, ncol=2,
          widths=c(1,0.25))


### End of script ###
